pdoc Documentation
==================

Requirements
------------

A Python 3 environment with ``pydoc3`` installed.

Build
-----
Build the HTML documentation by running:

    ./build.sh
    
The docs will appear in _./build_ directory.
